package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````]18``#0```"8@0````0`!30`(``)
M`"@`&P`:``$``'`X?```.'P``#A\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!$?```1'P```4```````$`
M`0```*Q]``"L?0$`K'T!`)0"``"H$@``!@```````0`"````M'T``+1]`0"T
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK'T`
M`*Q]`0"L?0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`#`G2>`J0[>\;.3M+I557'E[NR$\$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$P```!-````4```
M`%0```!5````70```%X```!?````80```&(```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````+!(````````#``L```````"``0``````
M`P`6`$`"`````````````!(```#A`@`````````````2````M0(`````````
M````(@```/H"`````````````!$```"G`P`````````````2`````0``````
M````````(````*8!`````````````!(```"4`@`````````````2````T@(`
M````````````$@```/@``````````````!(````6`P`````````````1````
M6P(`````````````$@```%P!`````````````!(```!'`@`````````````2
M````=```````````````$@```/,``````````````!(```!B`@``````````
M```2````)`(`````````````$@```.H!`````````````!(````$`P``````
M```````2````^P$`````````````$@````@"`````````````!(```#1````
M```````````1````3@$`````````````$@```+,``````````````!$````<
M`0`````````````2````FP(`````````````$@```(T"`````````````!$`
M``"*`0`````````````2````L@$`````````````$@```'<!````````````
M`!(```![`@`````````````2````JP$`````````````$@```(,!````````
M`````!(```#H`@`````````````2````*@$`````````````$@```!T`````
M`````````"`````=`@`````````````2````U`$`````````````$@```#("
M`````````````!(```!4```````````````2````I`(`````````````$@``
M`(,``````````````!(```"5`0`````````````2````Q`(`````````````
M$@```(\``````````````!(```!#`0`````````````2`````@(`````````
M````$@```#D"`````````````!(````)`0`````````````2````1@``````
M````````$@```/T``````````````!(```!L`0`````````````2````30(`
M````````````$@```,```````````````!(````6`@`````````````2````
MV@(`````````````$@```-P``````````````!(````K`@`````````````2
M````8P``````````````$@```/L"`````````````"$```"K`@``````````
M```2````I```````````````$@```#H!`````````````!(````L````````
M```````@````_`(`````````````$0```(,"`````````````!(```#9`0``
M```````````2````$`(`````````````$@```,X!`````````````!(```!P
M`@`````````````2````X0$`````````````$@```+H!`````````````!(`
M``#$`P``5)`!```````0`!<`L`,``#$M`````0``$@`-`.@#``"!)0``Z`4`
M`!(`#0#U`@``.14``+P!```2``T`=@,``"T>```$````$@`-`(<#``!`@`$`
M`````!``%P"$!```,1X``-`!```2``T`N@0``&DK``#(`0``$@`-`'`$``!`
M@`$``````!``%P#/`P```2```!8````2``T`]0,``$$Z``#6````$@`-``T$
M```P/```!````!$`#P!,!```5)`!```````0`!<`400``%20`0``````$``7
M`'P$``!-'0``.````!(`#0"1!```H20``.`````2``T`HP0``!DD``!X````
M$@`-```$````@`$``````!``%@#<`P``&2```!0````2``T`O`,``$"``0``
M````$``6`$($```\@`$`!````!$`%@!F`P``%3P```(````2``T`,@0``-4[
M``!`````$@`-``8$``#U%@```````!(`#0"Q!```R3D``'@````2``T``@0`
M``"``0``````(``6`)4#``"1)```$````!(`#0##`P``5)`!```````0`!<`
M'`0``(4=``"H````$@`-`&8$```9.P``O````!(`#0!9!```+2```.P#```2
M``T``%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`7U]E<G)N;U]L;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F
M7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD
M+6QI;G5X+6%R;6AF+G-O+C,`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT
M7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?
M96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O
M9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0``````````@`"``(``@`"
M`````P`"``(``@`$``(````"```````"``(``@`"``(``@````````````(`
M`@````,````"``,``@`"```````"``(``@````(````#``(```````(``@``
M``````````(````"``(````"`````@`"``````````(``@`"``(``P`"``(`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0!2`P``$````"`````4:6D-```$`-`$
M`````````0`!`#@#```0````(````!1I:0T```,`T`0````````!``$`2`,`
M`!``````````%&EI#0```@#0!````````*Q]`0`7````L'T!`!<```#$?P$`
M%P```.A_`0`7````\'\!`!<````$@`$`%P````R``0`7````$(`!`!<````8
M@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"B``0`7````,(`!`!<`
M```T@`$`%P```#R``0`7````R'\!`!4%``#,?P$`%0@``-!_`0`5#0``U'\!
M`!4/``#8?P$`%1D``-Q_`0`5&P``X'\!`!4>``#D?P$`%2<``.Q_`0`5-```
M]'\!`!4^``#X?P$`%4,``/Q_`0`51```T'X!`!8#``#4?@$`%@0``-A^`0`6
M!0``W'X!`!8'``#@?@$`%@D``.1^`0`6"@``Z'X!`!8+``#L?@$`%@P``/!^
M`0`6#@``]'X!`!80``#X?@$`%A$``/Q^`0`6$@```'\!`!83```$?P$`%A0`
M``A_`0`6%0``#'\!`!86```0?P$`%A<``!1_`0`6&```&'\!`!8:```<?P$`
M%AP``"!_`0`6'0``)'\!`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8B```T
M?P$`%B,``#A_`0`6)```/'\!`!8E``!`?P$`%B8``$1_`0`6)P``2'\!`!8H
M``!,?P$`%BD``%!_`0`6*@``5'\!`!8K``!8?P$`%BP``%Q_`0`6+0``8'\!
M`!8N``!D?P$`%B\``&A_`0`6,```;'\!`!8Q``!P?P$`%C(``'1_`0`6,P``
M>'\!`!8U``!\?P$`%C8``(!_`0`6-P``A'\!`!8X``"(?P$`%CD``(Q_`0`6
M.@``D'\!`!8[``"4?P$`%CP``)A_`0`6/0``G'\!`!9```"@?P$`%D$``*1_
M`0`60@``J'\!`!9%``"L?P$`%D8``+!_`0`61P``M'\!`!9(``"X?P$`%DD`
M`+Q_`0`62@``P'\!`!9+```(0"WI00$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M?&P!``#&C^(6RHSB?/R\Y0#&C^(6RHSB=/R\Y0#&C^(6RHSB;/R\Y0#&C^(6
MRHSB9/R\Y0#&C^(6RHSB7/R\Y0#&C^(6RHSB5/R\Y0#&C^(6RHSB3/R\Y7A'
M_><`QH_B%LJ,XD#\O.4`QH_B%LJ,XCC\O.4`QH_B%LJ,XC#\O.4`QH_B%LJ,
MXBC\O.4`QH_B%LJ,XB#\O.4`QH_B%LJ,XAC\O.5X1_WG`,:/XA;*C.(,_+SE
M`,:/XA;*C.($_+SE>$?]YP#&C^(6RHSB^/N\Y0#&C^(6RHSB\/N\Y0#&C^(6
MRHSBZ/N\Y0#&C^(6RHSBX/N\Y0#&C^(6RHSBV/N\Y0#&C^(6RHSBT/N\Y0#&
MC^(6RHSBR/N\Y0#&C^(6RHSBP/N\Y0#&C^(6RHSBN/N\Y0#&C^(6RHSBL/N\
MY0#&C^(6RHSBJ/N\Y0#&C^(6RHSBH/N\Y0#&C^(6RHSBF/N\Y0#&C^(6RHSB
MD/N\Y0#&C^(6RHSBB/N\Y0#&C^(6RHSB@/N\Y0#&C^(6RHSB>/N\Y0#&C^(6
MRHSB</N\Y0#&C^(6RHSB:/N\Y0#&C^(6RHSB8/N\Y0#&C^(6RHSB6/N\Y0#&
MC^(6RHSB4/N\Y0#&C^(6RHSB2/N\Y0#&C^(6RHSB0/N\Y7A'_><`QH_B%LJ,
MXC3[O.4`QH_B%LJ,XBS[O.4`QH_B%LJ,XB3[O.4`QH_B%LJ,XAS[O.4`QH_B
M%LJ,XA3[O.4`QH_B%LJ,X@S[O.4`QH_B%LJ,X@3[O.4`QH_B%LJ,XOSZO.4`
MQH_B%LJ,XO3ZO.4`QH_B%LJ,XNSZO.4`QH_B%LJ,XN3ZO.4`QH_B%LJ,XMSZ
MO.4`QH_B%LJ,XM3ZO.4`QH_B%LJ,XLSZO.4`QH_B%LJ,XL3ZO.4`QH_B%LJ,
MXKSZO.4`QH_B%LJ,XK3ZO.4`QH_B%LJ,XJSZO.4`QH_B%LJ,XJ3ZO.4`QH_B
M%LJ,XISZO.4`QH_B%LJ,XI3ZO.4`QH_B%LJ,XHSZO.5PM5M-B+!;2WU$6TS-
MZ000!:@#D@2I`ZI\1.M8&V@'DT_P``/_]T+O5$I52Z)8X%@11@+P5?M32^-8
M'7@`+6O044OD6"!H__?6[P-&(&B3^,8C0O`"`H/XQB/_]\SO!9V0^,8S*AT#
M-4/P`0.R\8!/@/C&,W/2D`#_]]SN0TI$2WI$!)Q[1!)H(6B"8$%*6&!Z1`6;
MPF!`2@$K`6!Z1$)@7]TA'03K@PX`\0P,4?@$2TSX!$]Q1?G1`S,X3@`A`)$J
M1GY$0/@C$#5)`T9Y1/!H__<P[P1&>+,R30:N?43H:/_WBNXP2#%&>$0`\._X
M0+,N2WM$V&C_]U+N__<0[RQ*'$MZ1--8&F@'FUI`3_```RG1($8(L'"]__>`
M[B5*>D308!"S__<T[A=+Y%@@:/_W8N^`^'U7A>?P:/_W,N\$1LKGJ&@0L0'P
M5_O1YQI(,49X1`#PN_BH8``HR=#SY__W".\$(ZGG__<N[@$@__>2[H!I`0`,
M`0``<&D!`"@!```P`0``&`$``!0!``"`:@$`A&H!`"@J```8*@``1FH!`-T&
M```L:@$`F"<``!9J`0"&:`$`ZFD!`-`F``!/\``+3_``#@*\:D8$M`&TW_@D
MH`BCFD3?^"#`6O@,P$WX!,T&2UKX`S`&2%KX``#_]SKN__?H[IAG`0```0``
M)`$``"P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$6___J>&<!`"`!```&
M2`=+!TIX1'M$>D2#0@/0!4O36`.Q&$=P1P"_UF@!`-1H`0!69P$`"`$```A(
M"4EX1`E*>40)&GI$RP\#ZZ$!21`#T`5+TU@#L1A'<$<`OZQH`0"H:`$`*&<!
M`#0!```(M0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W1.W_][__!DL!(GM$
M&G`(O79H`0#X9@$`!`$``"IH`0!6:`$`Q.<`ORWI^$.!1A]+>T0`*#;0'DJ;
M6-/X`("X\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'8^`!`;+%&1B!&*D9)1O_W
M5NX0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZPD%X>>F
MZP@&`34L1+80/F`@1KWH^(,$1N?G1$;EY[1F`0`X`0``.$HY2WI$+>GP09ZP
MTU@;:!V33_```Q"Q`W@$1F.Y,THQ2WI$TU@::!V;6D!/\``#5M$>L+WH\('_
M]U;M!48`*.W0*T]_1"A&__?R[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0
M($;_]V[M@$8P1O_W:NU`1`(P__="[3M&3_#_,@$A`98&1@"4__=\[0*J,48#
M(/_WWNT!,#!&!=`&FP/T<$.S]8!/%]#_]^[L,$;_][#L*$;_][SM`"C(T2A&
M__?F[2!&__>R[*CG<W@N*\G1LW@`*[;0Q>?_]Y'_YN?_]\3L+&8!``P!```.
M9@$`)"0``-_X9,`92_Q$$+4$1IRP`R!<^`,P:D8A1AMH&Y-/\``#__>V[:"Y
M!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@::!N;6D!/\``#"]$<L!"]`"#Q
MYP(A($;_]U[ML/J`\$`)Z>?_]XCL-F4!``P!````90$`$+4$1O_W[.Q#'B-$
MG$(XOQI&`],JX!-&HD(GT!-&$O@!&2\I]]"<0B#2`3N<0A_0&G@O*OG1`3L#
MX!%X`3LO*0+1&D:<0OC3$AN3'+/U@%^(OP`@"=@.2"%&3_2`4P$R>$0$1O_W
M0.P@1A"]G$+BT2-X+RL%T`=(O>@00'A$__<YO`5(O>@00'A$__<SO`"_^&4!
M`(PB``!((@``+>GP0P1&+$@.1BQ)>$2M]8!=@[#?^*B`#?6`4P&O05A`]O]R
M)T@$,PEH&6!/\``!.49X1/A$__<^[+#Q``P;W0*M#/'_.4U$%?@$/(.[N?$`
M#Q'02D8O(3A&__?0[%BQ&4M8^`,P&&C_]Q;M2T8Z1B%&__?B[`G@$TM8^`,P
M&&C_]PKM,D8A1O_W#NP/20WU@%,*2@0S>42*6!%H&FA10$_P``(&T0WU@%T#
ML+WH\(/A1L_G__?8ZR!D`0`,`0``^&,!`#XB```4`0``EF,!`%E*6DMZ1"WI
M\$<,1H*P!4;36-_X7($;:`&33_```PMX^$0]*PB_`30@1O_W).QI1@9&*$;_
M]S3^@48`*%;0__<:[(9"2=E+2P"?6/@#@+\`*W@`*QB_/2L4OP$C`",'T"M&
M$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WV.OP4?BQV/@`,"A&`)I3^"(0$/@!
M.PMP`"L8OSTK"=!*'!#X`3L11@+X`3L]*QB_`"OVT0I&/2,+<!3X`3L"^`$_
M`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]Z/"'"?'_.13X`3L)^`$_`"OY
MT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ`0D`*OC1`S&)`!M*>D03:+NY
M"$8!(Q-@__>&ZX)&`"C,T#E&3^J)!SI&__<`Z\CX`*`)\0$#`")*^",@S?@`
MD(3G.$;_]SKK@D;(^````"BTT$_JB0?LYYE&""'5Y__W&NL`OUAC`0`,`0``
M/&,!`#@!``"88@$`S&,!`#"U$4P12X.P?$3E6"AH__<<["AH__<8[`U*#DL.
M27M$HEAY1/_WDNLH:/_W#NP+2PM*`"0+27M$>D3-Z0`T>43_]Z[K`[`PO=1A
M`0`4`0``$`$``')>```.(```SB(``$D.```.(```$+4(3`A+?$3C6!AH__?H
MZP9*!TL'27M$HEAY1+WH$$#_]UZ[;F$!`!0!```0`0``$EX``*X?```D23"U
M)$IY1*WU`%V)L`WU`%,%K(I8'#,2:!I@3_```O_W#.L=24'R`0(=2WE$S>D`
M`7M$`2$@1O_W*NL-]8!1&#$@1D_T@%(#D?_WO.H$'KB_`"4*VV`<__?8Z@5&
M*+$#F2)&__=BZ@`C*U4-20WU`%,)2APS>42*6!%H&FA10$_P``($T2A&#?4`
M70FP,+W_]W+J-F$!``P!``"D'P``DA\``,9@`0#_]ZJ_+>GP3P9&94QE2JWU
MA%U\1(.P9$@-]813!J\$,Z)8#49X1#E&$F@:8$_P``+_]]+\+R$$1C!&__?$
MZL"Q6D@Q1GA$__=W_C!&6$D-]8135$H$,WE$BE@1:!IH44!/\``"0/"9@`WU
MA%T#L+WH\(\P1O_WFNI.28!&*$9Y1/_W`NL`*-O02TN#1M_X+)%[1`632DOY
M1'M$!).;^``P`"M0T"RQ648@1O_WP.D`*%706$;_]WKJ`/'_/(9&"^L,`QOX
M#"`O*A#1@AZLZP,,6D081M(:3_``"H/X`*`#ZPP.$T00^`$=+RGVT`CQ`0.>
M1+[U@%^CVC)*(:T!(4M&>D0H1LWI`29/](!2S?@`L/_W:NHZ1BE&`R#_]\[J
M*+D*FP/T<$.S]0!/(M`F20`@>43_]ZKJ@T:[\0`/@-";^``P`"NNT1RS(W@N
M*P30W?@4L$_P`0[)YV-X`"OWT1M)`"!Y1/_WD.J#1KOQ``_FT6;G`2$H1O_W
M?.H`*-;1%$@I1GA$__?8_2A&__><Z5WGW?@0L$_P`0ZHY__WFND`OX)@`0`,
M`0``"!\``/0>```^8`$`RAX```P>``"V'@``!!X``-0=```8'@``YAT``+8=
M```#>#NQ0APO*PB_$$82^`$[`"OXT7!'`+\0L0-X`['KY`%(>$3_]V*YIAP`
M`-U*W_AXP]Y+>D1PM?Q$#/$,#(RPVT[36`WQ"`Y^1`&L&V@+DT_P``/73;SH
M#P"NZ`\`?42\Z`\`KN@/`-SX`#"N^``P(48P1O_WQONPL<]+`9CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>P^P`HZ-'$3GY$(48P1O_W
MJ/NPL<!+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>2
M^P`HZ-&V3GY$(48P1O_WBONPL;%+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__=T^P`HZ-&H3GY$(48P1O_W;/NPL:)+`9CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=6^P`HZ-&:3GY$(48P1O_W
M3ONPL9-+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<X
M^P`HZ-&,3GY$(48P1O_W,/NPL81+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__<:^P`HZ-%^3GY$(48P1O_W$ONPL75+`9CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?\^@`HZ-%P3GY$(48P1O_W
M]/JPL69+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?>
M^@`HZ-%B3GY$(48P1O_WUOJPL5=+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__?`^@`HZ-%43GY$(48P1O_WN/JPL4A+`9CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>B^@`HZ-%&3GY$(48P1O_W
MFOJPL3E+`9CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>$
M^@`HZ-$X2"%&>$3_]WWZ`488L39(>$3_]R?\-4@A1GA$__=R^@%&&+$R2'A$
M__<<_#%((49X1/_W9_H!1JBQ+TAX1/_W$?PN22Y(>41X1/_W"_PM2A9+>D33
M6!IH"YM:0$_P``,=T0RP<+TH2"%&>$3_]TKZ`48@L25(>$3_]_3[X><D20HB
M#?$9`'E$__>RZ``HV-$@2`WQ(P%X1/_WY/O1Y_[WKN\`OXQ>`0`\6P``#`$`
M`#@=``!B7@$`.`$``.(<``"N'```?AP``$H<```>'```@AL``+(;``""&P``
M4AL``)X:``#D&@``P!H``.(:``"F&0``X!H``!P:``#Z&@``8!H``&Y;`0"V
M&@``3AH``*X:```N&@``%TL821A*>T1Y1`"U&&B#L(I80QP2:`&23_```@S0
M$TH12WI$TU@::`&;6D!/\``#$]$#L%WX!/L-2&E&>$3_]]7Y,+$`>#`H&+\`
M*!2_`2``(`A+>T088.'G_O=$[P"_YEL!`*!:`0`,`0``AEH!`'`9``"86P$`
M"+7^]_KN_O?L[@"Q`&@(O2Y*+TMZ1/"U+DZ'L`5&TUA^1`2I,$8;:`633_``
M`__WH?D0L0-X!$:+N2=*)$MZ1--8&F@%FUI`3_```SS1(T@I1GA$!["]Z/!`
M__<[NRE&_O>L[EBQ'DH92WI$TU@::`6;6D!/\``#)M$'L/"]*$;^]V+O!T8@
M1O[W7N\X1`(P_O<V[Q-+%$H!(7M$`I1Z1`"5`9)/\/\R!$;^]VSO#TH'2WI$
MTU@::`6;6D!/\``#!+\A1C!&Q=#^]]#N'%H!``P!``"4&0``\ED!`&(9``#&
M60$`3A@``$88``!^60$`+>GP3]_X3%6M]0%-W_A(18&P?41\1$"O(AVG\70#
M!Y`-]0!!W_@T!03Q$`S\,2@TI_%H#M_X**6G\>`&*%BG\5P%^D0`:`A@3_``
M``?*@^@'`+SH#P`/Q9SH`P"%Z`,`E.@'`([H!P#?^/@$,49X1/_W"/D@L0-X
M!$8`*T#P8('^]T+N_O<T[@`H`/!Q@05H`"T`\)>!*$;^]][N0``!,/[WMNXJ
M>(!&@K'?^+RT1$;[1"!&`));1D_P_S(!(0(T_O?H[A7X`2\`*O+1W_B<!*?Q
M6`5X1`+@5?@$"XBQ,4;_]]#X!$8`*/;0`W@`*_/0__>(^0`H[]`@1O[W.NX$
M1M"Y3_``":?Q=`L'ZXD"4OAT3(2Q"?$!!0OKA04B>%*Q($8)\0$)__=M^0`H
M7-%5^`1+`"SRT0`D($;^]X[N@T9`1O[WBNY81`#R!$M81O[W8.[?^!PT3_#_
M,@$A>T0"D]_X$#3-^`R`@$9[1`&3W_@(-`"4>T3^]X[N3_3@<4!&_O><[@$P
M!='^]W[N`6@1*4#PQH`R1D%&`R#^]_SN!49(L_9)!YOV2EKX`0!/\``*&VAZ
M1,WX`(`!(0!H_O><[O!)#?4`0^5*_#-Y1(I8$6@::%%`3_```D#PNH%01@WU
M`4T!L+WH\(\@1O[WPNT$1@`HBM"@YU?XT#P#]'!#L_6`3\[15_C(3/[W?NV$
M0LC15_C0/,/S"`.S]>!_P=%81O[W]NV"1MA(,49X1/_W*O@`*`#PR8`'FQQH
M_O>:[0%&($;_]S7[@T8`*`#PO8!81O[W`NX$1@,H#]G,200X6$1Y1/[W.NU`
MN00L`/`N@5Q$%/@%/"\K`/`H@<5,?$0C:%H<`/"E@``K`/"W@,%)PDAY1-_X
M")-X1,%/__>C^<%._O?.[<!+3_#_,@$A>T0#D[Y+^43-^`"`?T1[1,WI`3"[
M2U!&?D1[1/[WY.T4X/[WW.T#:!$K%]'^][+M`36$1DM&(D8!(5!&S>D#5\WI
M`6S-^`"`_O?.[4_TX'%01O[WWNT$1D,<XM!`1O[W#.VI2%%&>$3_]V;Y4$;_
M]P'^3^>62@>;6O@"`$_P``H;:*)*S>D`@0$A>D0`:/[WWNT_Y__W[OV=285*
M#?4`0WE$_#.*6!%H&FA10$_P``)`\/B`($8-]0%-`;"]Z/!/_O?^O(!&I_%H
M!`?KB`-3^&@,R+$(\0$+!.N+!03@5?@$"XBQ"_$!"S%&V$;^]W3_`"CTT`-X
M`"OQT/[WY.P%1@`H?_1RKN#G@DT-(/[W*NU3(H!&?41RYJA&U.<'F]/X`+`^
MYWQ(,49X1/[W5?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1)KUA&
M`"'^]P+M!$8`*#_T0:]/\/\S;_`1`@(F/1\`EO[WXNP&(BE&($;^]VSL%_@$
M/!NY%_@#/$,K8=``(P`B`),@1@`C_O?0[`'P`?@&1@/@*48P1@'P-_A/]`!"
M*48@1O[W4.P"'O/<W_ADL2!&I_$P"?[WC.VG\44%,4;[1$Q&I_$Q!J?Q1``!
M\(GX%?@!+R!&`));1D_P_S(!(?[W_NP"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI
M`((`(@?X""Q[1$9*>D0#DD_P_S+^]^;L'N<'FUQH`"P_]-.N($;^]\#L`RA_
M]LVN/4D$."!$>43^]_;K`"@(OZ-&PN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX
M2"N2T7MX12N/T4_P_S-O\#D"($8`EO[W7NPI1BDB($;^]^CK*TLK24_P_S)[
M1,WI`E,I2WE$4$;-Z0"!>T0!(?[WI.S;YO[W%.PN60$`<%H!``P!``#^6`$`
M:A<``"P8``!X%@``E!<``!86``!P%P``'`$``((7``!V5P$`7A<``#`7```(
M6`$`,!8``*X5```.%P``L!<``+P4``"\%P``QA0``.H6``#&%```PA4``/15
M`0`4%0``<!0``&84``#6$@``Z!0``*P5``"R%```,A4``$(2``!:%```7TA@
M27A$\+5?2X.P7TI!6'M$;D8):`&13_```9Q8(&C^]]#L!48@:/[WS.PQ1I7X
M:#"`^&DP5DAX1/[W+_X0L0-X,2MZT/_W/?H@:/[WNNQ020,C`2)Y1/[W\NL%
M1FBQ(&C^][#L*VE+2AEH>D3^][+K*VD;:)MH6P)NU"!H_O>B[$9)`R,!(GE$
M_O?:ZP5&>+%#2#%&>$3^]P#^!T8@:``O3]#^]X[L*VDZ1AEH_O>2ZR!H_O>&
M[`5&(&C^]X+L.$D!(GE$_O?FZS=*`48H1GI$-DW^]W[K(&C^]W3L`T9]1#-(
M`"(Q1GA$@_AI(/[WU?T$1JA@L+%/].!Q($;^]^KK0AP#1A$H&+\!*B_8*4H<
M2WI$TU@::`&;6D!/\``#(]$#L/"]:&C_]W;\!$:H8``HX=$@2'A$_O>^ZT-X
M`"N#T(#G_O<^[!Q+*FE[1!!H6V@9:/[WZOZKYR!H_O<R["MI&6C^]\CKB.?^
M]Q3K%$DB1A1(>41X1$EH"6C^]YSK5%,!``P!``!(4P$`%`$```@2``"6$P``
MA!,``'`3``!F$0``.!,``$03``#X4P$`"!$``$92`0#F$@``C%,!`&13`0#*
M$@``-THX2WI$\+4'1H.PTU@;:`&33_```P`H1-`#>``K0=#^]U+^!$8C>#NQ
M8APO*PB_%$82^`$[`"OXT2M./1X8OP$E?D0S:%H<,M``*PR_`"4%\`$%7;DE
M2B)+>D336!IH`9M:0$_P``,XT0.P\+T[>``K\-`>200B($9Y1/[WH.L`*.C1
M&TH72WI$TU@::`&;6D!/\``#(=$X1@.PO>CP0/[W7KT42'A$_O>*Z@1&NN<2
M2&E&>$3^]PW]:+$#>``K&+\P*PJ_`",!(S-@P]`!(S-@`"V_T,KG,&"\Y_[W
M=NJ,40$`#`$``))2`0`V40$`QA````A1`0#R#@``X`\``"WI\$\`\4`!W_B`
M2]_X@#NM]2-]?$3N1G)&`/&`#``GXU@;:*&33_```U'I`F178-=@$#(VND+X
M$&PC"B4"`_1_0P@Q0^H48P7T?P5#Z@1C845#Z@4#0O@(/.;1K?$(!@[U_'<`
M(X1&-$96^`@/U.D&A2)OU/A(H&%OU/A,D(+J"@)T:(+J"`*!Z@D!0D!I0,;X
MA#!A0)08T@^^0D+J00)"Z@0"QOB`(-[18$;>^`!`W.D#)H%HW.D`>4_JD0X"
MG4[J@GY']ID2Q?:"(D[J@7X!:D_JUVRD&$SJ21QD&(%I3.I''-WX$(`<ZP0$
MANH!#(%HW?B@H`SJ`0R!:8SJ`0P4ZPP$ANH.#*T8#.H'#&T8C.H&#!7K#`P8
MZP(%3^J7"*T92.J)>-WX&)!(ZH=X#.OT;([J"`$A0$_JM`2!Z@X!;1@9ZP(!
M$>L.`8CJ!`[=^""0#NH,#H[J"`X%Z_QE$>L.#D_JO`P9ZP(!W?@HD!'K"`&$
MZ@P(".H%"`[K]6Z(Z@0(3^JU!1'K"`$9ZP()C.H%"!GK!`0(Z@X(W?@PD`'K
M_F&(Z@P(3^J^#A3K"`09ZP()A>H."!GK#`P(Z@$(W?@XD`3K\62(Z@4(3^JQ
M`1SK"`P9ZP()CNH!"!GK!04(Z@0(W?A`D`SK]&R(Z@X(3^JT!!7K"`49ZP()
M@>H$"!GK#@X(Z@P(W?A(D`7K_&6(Z@$(3^J\#![K"`X9ZP()A.H,"!GK`0$(
MZ@4(W?A0D`[K]6Z(Z@0(3^JU!1'K"`$9ZP()C.H%"!GK!`0(Z@X(W?A8D`'K
M_F&(Z@P(3^J^#A3K"`09ZP()A>H."!GK#`P(Z@$(W?A@D`3K\62(Z@4(3^JQ
M`1SK"`P9ZP()CNH!"!GK!04(Z@0(W?AHD`SK]&R(Z@X(3^JT!!7K"`49ZP()
M@>H$"!GK#@X(Z@P(W?APD`7K_&6(Z@$(3^J\#![K"`X9ZP()A.H,"!GK`0$(
MZ@4(W?AXD`[K]6Z(Z@0(3^JU!1'K"`$9ZP()C.H%"!GK!`0(Z@X(W?B`D`'K
M_F&(Z@P(3^J^#A3K"`09ZP()A>H."!GK#`P(Z@$(W?B(D`3K\62(Z@4(3^JQ
M`1SK"`P9ZP()CNH!"!GK!04(Z@0(W?B0D(CJ#@@,Z_1L%>L("$_JM`09ZP()
M)IT9ZPX.@>H$"0GJ#`D(Z_QHB>H!"4_JO`P>ZPD.JAA1&(3J#`("Z@@"#NOX
M;F)`3^JX!8D83O:A,L;VV6+=^*B`&NL""@'K_F$:ZP0$C.H%"HKJ#@I/ZKX.
M%.L*!-WXL)`8ZP((A>H."@3K\62*Z@$*&.L,#$_JL0'=^+B`'.L*#!GK`@F.
MZ@$*#.OT;(KJ!`H9ZP4%3^JT!!7K"@7=^,"0&.L""('J!`H%Z_QEBNH,"ACK
M#@Y/ZKP,'NL*#MWXR("$Z@P*&>L""8KJ!0H9ZP$)#NOU81GK"@E/ZK4%&.L"
M"MWXT.`:ZP0*">OQ9(SJ!0F)Z@$)3^JQ`1KK"0H>ZP()W?C8@!GK#`D*Z_1L
MA>H!"HKJ!`I/ZK0$&>L*"1CK`@K=^.#@&NL%"@GK_&6!Z@0)B>H,"4_JO`P:
MZPD*'NL""=WXZ(`9ZP$)"NOU883J#`J*Z@4*3^JU!1GK"@D8ZP((W?CPX!CK
M!`@)Z_%DC.H%"8GJ`0E/ZK$!&.L)"![K`@[=^/B@'NL,#H7J`0P(Z_1HC.H$
M#$_JM`3=^`"1'NL,#AKK`@R!Z@0*#NOX;HKJ"`H<ZP4,3^JX"!SK"@Q"G83J
M"`H9ZP()#.O^;(KJ#@H9ZP$)3^J^#AGK"@E$F:T8B.H."HKJ#`HL&0GK_&5/
MZKP,%.L*!-WX&)&.Z@P*B1@$Z_5DBNH%"A'K"`%/ZK4%$>L*`8SJ!0H9ZP()
M`>OT88KJ!`K=^""!&>L."4_JM`L9ZPH)W?@HX0GK\608ZP((A>H+"1CK#`B)
MZ@$)3^JQ`1CK"0C=^##!'NL""HOJ`0Z.Z@0.&NL%"AKK#@H(Z_1E'.L"#$_J
MM`3=^#CA'.L+"X'J!`P*Z_5JC.H%#$_JM04;ZPP,'NL"`E(8A.H%`=WX0.&!
MZ@H!3^JZ"%$82_;<0LCV&W(,Z_IL'NL"#D7J"`H>ZP0$"NH,"@7J"`[=^$B1
M`>O\84KJ#@Y/ZKP,%.L.#AGK`@E(Z@P$".H,"AGK!04,0-WX4)$.Z_%N1.H*
M!$_JL0%E&1GK`@E,Z@$$&>L("@SJ`0O=^%B1!.H.!`7K_F5$Z@L$3^J^#A3K
M"@09ZP()&>L,"4'J#@P!Z@X*W?A@@0SJ!0P$Z_5D3.H*#$_JM04<ZPD,&.L"
M"!CK`0$,Z_1H3NH%#`[J!0K=^&B1#.H$#$SJ"@Q/ZK0$'.L!#!GK`@E%Z@0!
M&>L."@7J!`O=^'"1`>H(`4_JN`Y!Z@L!#.OX;!'K"@$9ZP()&>L%"D3J#@D!
MZ_QE">H,"4_JO`'=^'B!!.H.#$GJ#`S=^("1'.L*#!CK`@@8ZP0$#.OU:$[J
M`0P.Z@$*#.H%#$_JM05,Z@H,0>H%"ASK!`09ZP(,!.OX9-WXB)$*Z@@*'.L.
M#$_JN`X!Z@4(2NH("`7J#@H8ZPP,&>L""$7J#@D8ZP$(">H$"6292>H*"0SK
M]&P9ZP@(3^JT!(D8#NH$"4T93NH$`0'J#`$(Z_QH0>H)`4_JO`Q-&6:91.H,
M"03J#`J)&`GJ"`D1ZPX.:)D%Z_AE2>H*"4_JN`@9ZPX)B1@,Z@@*$>L$#@GK
M]61,Z@@):ID)Z@4)3^JU!4GJ"@D9ZPX.B1@1ZPP,2.H%`0CJ!0DA0$'J"0$.
MZ_1N$>L,#&R93^JT!`SK_FR)&$7J!`D%Z@0*$>L("`GJ#@ENF4GJ"@E/ZKX.
M&>L("8D8$>L%"`GK_&5$Z@X)!.H."G"9">H,"4GJ"@E/ZKP,&>L("4[J#`B)
M&`CJ!0@)&0GK]60.Z@P)3^JU!4CJ"0A,Z@4)&.L!"'*9#.H%"@GJ!`F)&`CK
M]&@1ZPX.=)E/ZK0$2>H*"1GK#@F)&$7J!`X)Z_AI$>L,"@[J"`Y/ZK@,=ID%
MZ@0(0V!.Z@@.!.H,"![K"@Z*&%491.H,`@+J"0)XF4+J"`(.Z_EN51E,\M82
MS/9B(D_JN0D1ZP((>ID8ZP0(C.H)!(3J#@0%Z_YE&.L$"$_JO@Z)&(GJ#@01
MZPP,?)EL0`CK]6@<ZP0,3^JU!8D8CNH%!!'K"0E^F0SK^&R$Z@@$&>L$"4_J
MN`B,&("9%.L.!`GK_&Z%Z@@)PV")Z@P)3^J\#!3K"02)&$T9B.H,"8*9!.O^
M9(GJ#@E/ZKX.%>L)"8T8%>L(!829">OT:(SJ#@F)Z@0)3^JT!!7K"06)&!'K
M#`R.Z@0)AID%Z_AEB>H("4-A'.L)"4_JN`P1ZP((B)D8ZPX(">OU;H3J#`G#
M88GJ!0E/ZK4%&.L)"!'K`@D9ZP0)BID(Z_YDC.H%"(CJ#@A/ZKX.&>L("1'K
M`@@8ZPP(C)D)Z_1LA>H."8GJ!`E/ZK0$&.L)"!'K`@D9ZP4)CID(Z_QECNH$
M"(CJ#`A/ZKP,&>L("1'K`@@8ZPX(D)D)Z_5NA.H,"8GJ!0E/ZK4%&.L)"!'K
M`@D9ZP0)DID(Z_YDC.H%"(CJ#@A/ZKX.&>L("1'K`@@8ZPP(E)D)Z_1LA>H.
M"8GJ!`E/ZK0$&.L)"!'K`@D9ZP4)EID(Z_QECNH$"(CJ#`A/ZKP,&>L("1'K
M`@@8ZPX(F)D)Z_5NA.H,"8GJ!0E/ZK4%&.L)"(D8$>L$"0CK_F2:F8SJ!0B(
MZ@X(3^J^#AGK"`F)&!'K#`@)Z_1LA>H."9R9B>H$"4_JM`08ZPD(B1@(Z_QH
M31F>F0;KN`8&88[J!`:&Z@P&3^J\#*T9BAC7&83J#`(%Z_AE%^L.#H+J"`B"
M:![K"`ZI&`[K]6*%:0)@`FH<ZP4%@6"D&`M*P.D(0PE+>D2%8=-8&FBAFUI`
M3_```P/1#?4C?;WH\(_]]Z+L`+]\4`$`#`$``"1%`0`(M8`@_??@[)_M#WL`
M(H)G@.T`>Y_M#GN`[0)[G^T.>X#M!'N?[0Y[@.T&>Y_M#GN`[0A[G^T.>X#M
M"GN`[0Q["+T`OZ_S`(`!(T5G`````(FKS>\`````_MRZF`````!V5#(0````
M`/#ATL,````````````````MZ?A#!4861H-J`"`,1O<7U>D,(0/KQ@R<1>MJ
M<.L#`P/24QP:1D'Q``'%Z0K`<P^H;T/JQP.;&`7Q.`A!ZU=Q*V-I8X"[/RY#
MW:;Q0`E/ZID6=QP$ZX<7(49#1@3Q0`[1^`#`$#%1^`Q,$#-1^`@,4?@$+'%%
M0_@0S$/X#$Q#^`@,0_@$+.O1#$8H1O_WL/F\0N'1J>N&%C)&.49`1OWWZ.NN
M9[WH^(/`\4`'(4:W0D!$J+\W1CI&_??:ZZMO.T2K9T`K[M$H1O8;/$3_]Y#Y
MN><G1N#G`+\MZ?!!`?$X!PQ&BVH%1@YK@"&3^H/XP_/%`S:Z6ARX&#@J^51$
MW<+Q0`(`(?WW@.P@1O_W<?DX1C@B`"']]WCL($;$Z1QH__=G^>-X*W`@1F.(
M:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*JW&C:.MQXWPK<F.*:W(C:1L*JW(C
M:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C,"MT8XQK="-J&PJK="-JZW2]Z/!!
M_?=LN\+Q.`(`(?WW/.S!YRWI^$,'1@Q.#$V(1GY$D49]1/WW(NMV&[80"M`$
M/0`D5?@$/TI&048X1@$TF$>F0O;1O>CX@P"_S$$!`,1!`0!P1P"_`DM[1!MH
M_?=SNP"_YD,!``A`+>D(@+WH`0`"`#H````]````"@```#T````/````/0``
M`"0````]````,@```#T````"````/0````4````]````$P```#T````-````
M/0````P````]````(P```#T````1````/0```"8````]`````0```#T````7
M````/0````@````]````"0```#T``````````````"]T;7``````+@```%!!
M4E]435!$25(``%1%35!$25(`5$U0`%5315(`````55-%4DY!344`````)7,O
M)7,````O````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E
M>&4`4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%
M4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````
M4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-
M4$1)4@```%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!
M4E]#3$5!3CT``#$```!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X````
M`"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L````
M`"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ
M5D524TE/3@`````Q+C`U,@```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA
M<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE
M(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H
M;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O
M<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E
M:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I
M.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I
M9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T
M("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(
M.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN
M+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F
M+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@
M)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI
M.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^
M>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@
M;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A
M7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?
M1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@
M)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D[
M"F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B
M=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC
M;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A
M=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M
M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@``<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("``````.@```#T````*````/0````\````]````
M)````#T````R````/0````(````]````!0```#T````3````/0````T````]
M````#````#T````C````/0```!$````]````)@```#T````!````/0```!<`
M```]````"````#T````)````/0``````````````O)K_?P$`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````1@`
M`,$7```!````*`,```$````X`P```0```$@#```!````4@,```P````L$@``
M#0```"@\```9````K'T!`!L````$````&@```+!]`0`<````!````/7^_V^T
M`0``!0```%0)```&````I`(```H```#:!```"P```!`````5``````````,`
M``#$?@$``@```.@!```4````$0```!<```!$$```$0```&0/```2````X```
M`!,````(````'@````@```#[__]O`0``"/[__V\$#P``____;P,```#P__]O
M+@X``/K__V\0````````````````````````````````````````````````
M`````````+1]`0```````````#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``
M.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X
M$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```5/```````
M``````````````````````````````````````#5.P```````#D5````````
M````````````````!(`!`/_____$/```S#P```````#0/```U#P``-P\``!@
M/0``Y#P```````#H/```\#P```````#X/P``1T-#.B`H56)U;G1U(#$P+C(N
M,2TV=6)U;G1U,BD@,3`N,BXQ(#(P,C$P,3(Q`$$R````865A8FD``2@````%
M-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D
M871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M````````"P````$````"````5`$``%0!```9```````````````!````````
M`!,````'`````@```'`!``!P`0``)```````````````!``````````F````
M!P````(```"4`0``E`$``"````````````````0`````````-````/;__V\"
M````M`$``+0!``#P````!0`````````$````!````#X````+`````@```*0"
M``"D`@``L`8```8````#````!````!````!&`````P````(```!4"0``5`D`
M`-H$``````````````$`````````3@```/___V\"````+@X``"X.``#6````
M!0`````````"`````@```%L```#^__]O`@````0/```$#P``8`````8````#
M````!`````````!J````"0````(```!D#P``9`\``.`````%``````````0`
M```(````<P````D```!"````1!```$00``#H`0``!0```!4````$````"```
M`'P````!````!@```"P2```L$@``#```````````````!`````````!W````
M`0````8````X$@``.!(````#``````````````0````$````@@````$````&
M````.!4``#@5``#P)@`````````````(`````````(@````!````!@```"@\
M```H/```"```````````````!`````````".`````0````(````P/```,#P`
M``A```````````````0`````````E@````$``'""````.'P``#A\```(````
M#0`````````$`````````*$````!`````@```$!\``!`?```!```````````
M````!`````````"K````#@````,```"L?0$`K'T```0```````````````0`
M```$````MP````\````#````L'T!`+!]```$```````````````$````!```
M`,,````&`````P```+1]`0"T?0``$`$```8`````````!`````@```#,````
M`0````,```#$?@$`Q'X``#P!``````````````0````$````T0````$````#
M`````(`!``"```!````````````````$`````````-<````(`````P```$"`
M`0!`@```%!``````````````!`````````#<`````0```#``````````0(``
M`"X```````````````$````!````Y0````,``'```````````&Z````S````
M```````````!``````````$````#``````````````"A@```]0``````````
+`````0``````````
